@@ -12,15 +12,14 @@ from gunicorn import __version__
 #@validator
 def app(environ, start_response):
     """Simplest possible application object"""
-    data = 'Hello, World!\n'
+    data = b'Hello, World!\n'
     status = '200 OK'
-#    print("print to stdout in test app")
-#    sys.stderr.write("stderr, print to stderr in test app\n")
+
     response_headers = [
         ('Content-type','text/plain'),
         ('Content-Length', str(len(data))),
-        ('X-Gunicorn-Version', __version__)
+        ('X-Gunicorn-Version', __version__),
+        ("Test", "test тест"),
     ]
-
     start_response(status, response_headers)
     return iter([data])
