@@ -6,7 +6,11 @@
 import os
 import pkg_resources
 import sys
-import ConfigParser
+
+try:
+    import configparser as ConfigParser
+except ImportError:
+    import ConfigParser
 
 from paste.deploy import loadapp, loadwsgi
 SERVER = loadwsgi.SERVER
@@ -14,6 +18,7 @@ SERVER = loadwsgi.SERVER
 from gunicorn.app.base import Application
 from gunicorn.config import Config
 
+
 class PasterBaseApplication(Application):
 
     def app_config(self):
@@ -25,7 +30,7 @@ class PasterBaseApplication(Application):
         if host and port:
             cfg['bind'] = '%s:%s' % (host, port)
         elif host:
-            cfg['bind'] = host
+            cfg['bind'] = host.split(',')
 
         cfg['workers'] = int(lc.get('workers', 1))
         cfg['umask'] = int(lc.get('umask', 0))
@@ -51,19 +56,12 @@ class PasterBaseApplication(Application):
             parser = ConfigParser.ConfigParser()
             parser.read([self.cfgfname])
             if parser.has_section('loggers'):
-                if sys.version_info >= (2, 6):
-                    from logging.config import fileConfig
-                else:
-                    # Use our custom fileConfig -- 2.5.1's with a custom Formatter class
-                    # and less strict whitespace (which were incorporated into 2.6's)
-                    from gunicorn.logging_config import fileConfig
-
+                from logging.config import fileConfig
                 config_file = os.path.abspath(self.cfgfname)
                 fileConfig(config_file, dict(__file__=config_file,
                                              here=os.path.dirname(config_file)))
 
 
-
 class PasterApplication(PasterBaseApplication):
 
     def init(self, parser, opts, args):
@@ -87,6 +85,7 @@ class PasterApplication(PasterBaseApplication):
     def load(self):
         return loadapp(self.cfgurl, relative_to=self.relpath)
 
+
 class PasterServerApplication(PasterBaseApplication):
 
     def __init__(self, app, gcfg=None, host="127.0.0.1", port=None, *args, **kwargs):
@@ -107,7 +106,7 @@ class PasterServerApplication(PasterBaseApplication):
             bind = "%s:%s" % (host, port)
         else:
             bind = host
-        cfg["bind"] = bind
+        cfg["bind"] = bind.split(',')
 
         if gcfg:
             for k, v in gcfg.items():
@@ -118,18 +117,17 @@ class PasterServerApplication(PasterBaseApplication):
             for k, v in cfg.items():
                 if k.lower() in self.cfg.settings and v is not None:
                     self.cfg.set(k.lower(), v)
-        except Exception, e:
+        except Exception as e:
             sys.stderr.write("\nConfig error: %s\n" % str(e))
             sys.stderr.flush()
             sys.exit(1)
 
-
     def load_config(self):
         if not hasattr(self, "cfgfname"):
             return
 
         cfg = self.app_config()
-        for k,v in cfg.items():
+        for k, v in cfg.items():
             try:
                 self.cfg.set(k.lower(), v)
             except:
@@ -137,8 +135,9 @@ class PasterServerApplication(PasterBaseApplication):
                 raise
 
     def load(self):
-        if self.app is None and hasattr(self, "cfgfname"):
+        if hasattr(self, "cfgfname"):
             return loadapp(self.cfgurl, relative_to=self.relpath)
+
         return self.app
 
 
@@ -148,7 +147,8 @@ def run():
     apllications like Pylons or Turbogears2
     """
     from gunicorn.app.pasterapp import PasterApplication
-    PasterApplication("%prog [OPTIONS] pasteconfig.ini").run()
+    PasterApplication("%(prog)s [OPTIONS] pasteconfig.ini").run()
+
 
 def paste_server(app, gcfg=None, host="127.0.0.1", port=None, *args, **kwargs):
     """\
