@@ -24,14 +24,16 @@ import sys
 import textwrap
 import time
 import inspect
+import errno
+import warnings
 
 from gunicorn.six import text_type, string_types
 
 MAXFD = 1024
 if (hasattr(os, "devnull")):
-   REDIRECT_TO = os.devnull
+    REDIRECT_TO = os.devnull
 else:
-   REDIRECT_TO = "/dev/null"
+    REDIRECT_TO = "/dev/null"
 
 timeout_default = object()
 
@@ -83,7 +85,6 @@ except ImportError:
                                   "package")
         return "%s.%s" % (package[:dot], name)
 
-
     def import_module(name, package=None):
         """Import a module.
 
@@ -104,6 +105,7 @@ relative import to an absolute import.
         __import__(name)
         return sys.modules[name]
 
+
 def load_class(uri, default="sync", section="gunicorn.workers"):
     if inspect.isclass(uri):
         return uri
@@ -111,7 +113,7 @@ def load_class(uri, default="sync", section="gunicorn.workers"):
         # uses entry points
         entry_str = uri.split("egg:")[1]
         try:
-            dist, name = entry_str.rsplit("#",1)
+            dist, name = entry_str.rsplit("#", 1)
         except ValueError:
             dist = entry_str
             name = default
@@ -135,7 +137,8 @@ def load_class(uri, default="sync", section="gunicorn.workers"):
             mod = getattr(mod, comp)
         return getattr(mod, klass)
 
-def set_owner_process(uid,gid):
+
+def set_owner_process(uid, gid):
     """ set user and group of workers processes """
     if gid:
         try:
@@ -150,6 +153,7 @@ def set_owner_process(uid,gid):
     if uid:
         os.setuid(uid)
 
+
 def chown(path, uid, gid):
     try:
         os.chown(path, uid, gid)
@@ -159,17 +163,74 @@ def chown(path, uid, gid):
         os.chown(path, uid, -ctypes.c_int(-gid).value)
 
 
+if sys.platform.startswith("win"):
+    def _waitfor(func, pathname, waitall=False):
+        # Peform the operation
+        func(pathname)
+        # Now setup the wait loop
+        if waitall:
+            dirname = pathname
+        else:
+            dirname, name = os.path.split(pathname)
+            dirname = dirname or '.'
+        # Check for `pathname` to be removed from the filesystem.
+        # The exponential backoff of the timeout amounts to a total
+        # of ~1 second after which the deletion is probably an error
+        # anyway.
+        # Testing on a i7@4.3GHz shows that usually only 1 iteration is
+        # required when contention occurs.
+        timeout = 0.001
+        while timeout < 1.0:
+            # Note we are only testing for the existance of the file(s) in
+            # the contents of the directory regardless of any security or
+            # access rights.  If we have made it this far, we have sufficient
+            # permissions to do that much using Python's equivalent of the
+            # Windows API FindFirstFile.
+            # Other Windows APIs can fail or give incorrect results when
+            # dealing with files that are pending deletion.
+            L = os.listdir(dirname)
+            if not (L if waitall else name in L):
+                return
+            # Increase the timeout and try again
+            time.sleep(timeout)
+            timeout *= 2
+        warnings.warn('tests may fail, delete still pending for ' + pathname,
+                      RuntimeWarning, stacklevel=4)
+
+    def _unlink(filename):
+        _waitfor(os.unlink, filename)
+else:
+    _unlink = os.unlink
+
+
+def unlink(filename):
+    try:
+        _unlink(filename)
+    except OSError as error:
+        # The filename need not exist.
+        if error.errno not in (errno.ENOENT, errno.ENOTDIR):
+            raise
+
+
 def is_ipv6(addr):
     try:
         socket.inet_pton(socket.AF_INET6, addr)
-    except socket.error: # not a valid address
+    except socket.error:  # not a valid address
         return False
     return True
 
+
 def parse_address(netloc, default_port=8000):
     if netloc.startswith("unix:"):
         return netloc.split("unix:")[1]
 
+    if netloc.startswith("unix://"):
+        return netloc.split("unix://")[1]
+
+    if netloc.startswith("tcp://"):
+        netloc = netloc.split("tcp://")[1]
+
+
     # get host
     if '[' in netloc and ']' in netloc:
         host = netloc.split(']')[0][1:].lower()
@@ -197,15 +258,18 @@ def get_maxfd():
         maxfd = MAXFD
     return maxfd
 
+
 def close_on_exec(fd):
     flags = fcntl.fcntl(fd, fcntl.F_GETFD)
     flags |= fcntl.FD_CLOEXEC
     fcntl.fcntl(fd, fcntl.F_SETFD, flags)
 
+
 def set_non_blocking(fd):
     flags = fcntl.fcntl(fd, fcntl.F_GETFL) | os.O_NONBLOCK
     fcntl.fcntl(fd, fcntl.F_SETFL, flags)
 
+
 def close(sock):
     try:
         sock.close()
@@ -220,9 +284,10 @@ except ImportError:
         for fd in range(fd_low, fd_high):
             try:
                 os.close(fd)
-            except OSError:	# ERROR, fd wasn't open to begin with (ignored)
+            except OSError:  # ERROR, fd wasn't open to begin with (ignored)
                 pass
 
+
 def write_chunk(sock, data):
     if isinstance(data, text_type):
         data = data.encode('utf-8')
@@ -230,11 +295,13 @@ def write_chunk(sock, data):
     chunk = b"".join([chunk_size.encode('utf-8'), data, b"\r\n"])
     sock.sendall(chunk)
 
+
 def write(sock, data, chunked=False):
     if chunked:
         return write_chunk(sock, data)
     sock.sendall(data)
 
+
 def write_nonblock(sock, data, chunked=False):
     timeout = sock.gettimeout()
     if timeout != 0.0:
@@ -246,10 +313,12 @@ def write_nonblock(sock, data, chunked=False):
     else:
         return write(sock, data, chunked)
 
+
 def writelines(sock, lines, chunked=False):
     for line in list(lines):
         write(sock, line, chunked)
 
+
 def write_error(sock, status_int, reason, mesg):
     html = textwrap.dedent("""\
     <html>
@@ -273,8 +342,10 @@ def write_error(sock, status_int, reason, mesg):
     """) % (str(status_int), reason, len(html), html)
     write_nonblock(sock, http.encode('latin1'))
 
+
 def normalize_name(name):
-    return  "-".join([w.lower().capitalize() for w in name.split("-")])
+    return "-".join([w.lower().capitalize() for w in name.split("-")])
+
 
 def import_app(module):
     parts = module.split(":", 1)
@@ -288,7 +359,7 @@ def import_app(module):
     except ImportError:
         if module.endswith(".py") and os.path.exists(module):
             raise ImportError("Failed to find application, did "
-                "you mean '%s:%s'?" % (module.rsplit(".",1)[0], obj))
+                "you mean '%s:%s'?" % (module.rsplit(".", 1)[0], obj))
         else:
             raise
 
@@ -300,6 +371,7 @@ def import_app(module):
         raise TypeError("Application object must be callable.")
     return app
 
+
 def http_date(timestamp=None):
     """Return the current date and time formatted for a message header."""
     if timestamp is None:
@@ -311,9 +383,11 @@ def http_date(timestamp=None):
             hh, mm, ss)
     return s
 
+
 def is_hoppish(header):
     return header.lower().strip() in hop_headers
 
+
 def daemonize():
     """\
     Standard daemonization of a process.
@@ -335,6 +409,7 @@ def daemonize():
         os.dup2(0, 1)
         os.dup2(0, 2)
 
+
 def seed():
     try:
         random.seed(os.urandom(64))
@@ -349,6 +424,7 @@ def check_is_writeable(path):
         raise RuntimeError("Error: '%s' isn't writable [%r]" % (path, e))
     f.close()
 
+
 def to_bytestring(value):
     """Converts a string argument to a byte string"""
     if isinstance(value, bytes):
